@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2004-2008 by the cairo perl team (see the file README)
+# Copyright (c) 2004-2012 by the cairo perl team (see the file README)
 #
 # Licensed under the LGPL, see LICENSE file for more information.
 #
@@ -14,15 +14,23 @@ use DynaLoader;
 
 our @ISA = qw/DynaLoader/;
 
-our $VERSION = '1.070';
+our $VERSION = '1.090';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 Cairo->bootstrap ($VERSION);
 
-# --------------------------------------------------------------------------- #
-
-package Cairo;
+# Our Cairo::VERSION used to be a simple wrapper around CAIRO_VERSION.  But a
+# package's VERSION sub is supposed to do Perl version checking so that things
+# like 'use Cairo 1.00' work.  To not break backwards-compatibility, we
+# dispatch according to the number of arguments passed in.
+sub VERSION {
+  if (scalar @_ == 2) {
+    shift->SUPER::VERSION (@_);
+  } else {
+    Cairo::LIB_VERSION (@_);
+  }
+}
 
 1;
 
@@ -30,7 +38,7 @@ __END__
 
 =head1 NAME
 
-Cairo - Perl interface to the cairo library
+Cairo - Perl interface to the cairo 2d vector graphics library
 
 =head1 SYNOPSIS
 
@@ -256,6 +264,16 @@ C<$cr-E<gt>restore> to restore to the saved state.
 
 =item ($x1, $y1, $x2, $y2) = $cr->clip_extents [1.4]
 
+=item $bool = $cr->in_clip ($x, $y) [1.10]
+
+=over
+
+=item $x: double
+
+=item $y: double
+
+=back
+
 =item @rectangles = $cr->copy_clip_rectangle_list [1.4]
 
 =item $cr->reset_clip
@@ -343,8 +361,8 @@ C<$cr-E<gt>restore> to restore to the saved state.
   ];
 
 I<Cairo::Path> is a data structure for holding a path. This data structure
-serves as the return value for C<$cr-E<gt>copy_path_data> and
-C<$cr-E<gt>copy_path_data_flat> as well the input value for
+serves as the return value for C<$cr-E<gt>copy_path> and
+C<$cr-E<gt>copy_path_flat> as well the input value for
 C<$cr-E<gt>append_path>.
 
 I<Cairo::Path> is represented as an array reference that contains path
@@ -384,6 +402,18 @@ The semantics and ordering of the coordinate values are consistent with
 C<$cr-E<gt>move_to>, C<$cr-E<gt>line_to>, C<$cr-E<gt>curve_to>, and
 C<$cr-E<gt>close_path>.
 
+Note that the paths returned by Cairo are implemented as tied array references
+which do B<not> support adding, removing or shuffling of path segments.  For
+these operations, you need to make a shallow copy first:
+
+  my @path_clone = @{$path};
+  # now you can alter @path_clone which ever way you want
+
+The points of a single path element can be changed directly, however, without
+the need for a shallow copy:
+
+  $path->[$i]{points} = [[3, 4], [5, 6], [7, 8]];
+
 =over
 
 =item $path = $cr->copy_path
@@ -707,6 +737,90 @@ red, green, blue, and alpha.
 
 # --------------------------------------------------------------------------- #
 
+=head3 Regions -- Representing a pixel-aligned area
+
+=over
+
+=item $region = Cairo::Region->create (...) [1.10]
+
+=over
+
+=item ...: zero or more I<Cairo::RectangleInt>
+
+=back
+
+=item $status = $region->status [1.10]
+
+=item $num = $region->num_rectangles [1.10]
+
+=item $rect = $region->get_rectangle ($i) [1.10]
+
+=over
+
+=item $i: integer
+
+=back
+
+=item $bool = $region->is_empty [1.10]
+
+=item $bool = $region->contains_point ($x, $y) [1.10]
+
+=over
+
+=item $x: integer
+
+=item $y: integer
+
+=back
+
+=item $bool = $region_one->equal ($region_two) [1.10]
+
+=over
+
+=item $region_two: I<Cairo::Region>
+
+=back
+
+=item $region->translate ($dx, $dy) [1.10]
+
+=over
+
+=item $dx: integer
+
+=item $dy: integer
+
+=back
+
+=item $status = $dst->intersect ($other) [1.10]
+
+=item $status = $dst->intersect_rectangle ($rect) [1.10]
+
+=item $status = $dst->subtract ($other) [1.10]
+
+=item $status = $dst->subtract_rectangle ($rect) [1.10]
+
+=item $status = $dst->union ($other) [1.10]
+
+=item $status = $dst->union_rectangle ($rect) [1.10]
+
+=item $status = $dst->xor ($other) [1.10]
+
+=item $status = $dst->xor_rectangle ($rect) [1.10]
+
+=over
+
+=item $other: I<Cairo::Region>
+
+=item $rect: I<Cairo::RectangleInt>
+
+=back
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
 =head3 Transformations -- Manipulating the current transformation matrix
 
 =over
@@ -932,6 +1046,24 @@ I<x> and I<y>.  Example:
 
 =back
 
+=item $face = Cairo::ToyFontFace->create ($family, $slant, $weight) [1.8]
+
+=over
+
+=item $family: string
+
+=item $slant: I<Cairo::FontSlant>
+
+=item $weight: I<Cairo::FontWeight>
+
+=back
+
+=item $family = $face->get_family [1.8]
+
+=item $slang = $face->get_slant [1.8]
+
+=item $weight = $face->get_weight [1.8]
+
 =back
 
 =cut
@@ -1133,10 +1265,12 @@ from a file:
 
 =over
 
-=item $new = $old->create_similar ($content, $width, $height)
+=item $similar = Cairo::Surface->create_similar ($other, $content, $width, $height)
 
 =over
 
+=item $other: I<Cairo::Surface>
+
 =item $content: I<Cairo::Content>
 
 =item $width: integer
@@ -1145,6 +1279,26 @@ from a file:
 
 =back
 
+For hysterical reasons, you can also use the following syntax:
+
+  $similar = $other->create_similar ($content, $width, $height)
+
+=item $new = Cairo::Surface->create_for_rectangle ($target, $x, $y, $width, $height) [1.10]
+
+=over
+
+=item $target: I<Cairo::Surface>
+
+=item $x: double
+
+=item $y: double
+
+=item $width: double
+
+=item $height: double
+
+=back
+
 =item $status = $surface->status
 
 =item $surface->finish
@@ -1263,6 +1417,16 @@ from a file:
 
 =item $stride = $surface->get_stride [1.2]
 
+=item $stride = Cairo::Format::stride_for_width ($format, $width) [1.6]
+
+=over
+
+=item $format: I<Cairo::Format>
+
+=item $width: integer
+
+=back
+
 =back
 
 =cut
@@ -1309,6 +1473,24 @@ from a file:
 
 =back
 
+=item $surface->restrict_to_version ($version) [1.10]
+
+=over
+
+=item $version: I<Cairo::PdfVersion>
+
+=back
+
+=item @versions = Cairo::PdfSurface::get_versions [1.10]
+
+=item $string = Cairo::PdfSurface::version_to_string ($version) [1.10]
+
+=over
+
+=item $version: I<Cairo::PdfVersion>
+
+=back
+
 =back
 
 =cut
@@ -1469,6 +1651,28 @@ from a file:
 
 # --------------------------------------------------------------------------- #
 
+=head3 Recording Surfaces -- Records all drawing operations
+
+=over
+
+=item $surface = Cairo::RecordingSurface->create ($content, $extents) [1.10]
+
+=over
+
+=item $content: I<Cairo::Content>
+
+=item $extents: I<Cairo::Rectangle>
+
+=back
+
+=item ($x0, $y0, $width, $height) = $surface->ink_extents [1.10]
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
 =head3 SVG Surfaces -- Rendering SVG documents
 
 =over
@@ -1529,13 +1733,18 @@ from a file:
 
 =over
 
-=item $version = Cairo->version
+=item $version_code = Cairo->lib_version
 
-=item $string = Cairo->version_string
+=item $version_string = Cairo->lib_version_string
 
-=item $version_code = Cairo->VERSION
+These two functions return the version of libcairo that the program is
+currently running against.
 
-=item $version_code = Cairo->VERSION_ENCODE ($major, $minor, $micro)
+=item $version_code = Cairo->LIB_VERSION
+
+Returns the version of libcairo that L<Cairo> was compiled against.
+
+=item $version_code = Cairo->LIB_VERSION_ENCODE ($major, $minor, $micro)
 
 =over
 
@@ -1547,15 +1756,8 @@ from a file:
 
 =back
 
-=item $stride = Cairo::Format::stride_for_width ($format, $width) [1.6]
-
-=over
-
-=item $format: I<Cairo::Format>
-
-=item $width: integer
-
-=back
+Encodes the version C<$major.$minor.$micro> as an integer suitable for
+comparison against C<< Cairo->lib_version >> and C<< Cairo->LIB_VERSION >>.
 
 =back
 
@@ -1589,6 +1791,6 @@ Contains the reference manual
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004-2009 by the cairo perl team
+Copyright (C) 2004-2011 by the cairo perl team
 
 =cut
